@@ -3,10 +3,14 @@
 #' @title Convert Shapefile Layer to Spatial Polygon Dataframe
 #' @param dsn dsn argument to readOGR
 #' @param layerName layer argument to readOGR
-#' @description Raw shapefiles are read in using the \code{readOGR()} function from the \pkg{rgdal} package.
+#' @param encoding encoding string (.e.g. 'latin1') passed to rgdal::readOGR()
+#' @description Raw shapefiles are read in using the \code{rgdal::readOGR()} function from the \pkg{rgdal} package.
 #' Spatial data are reprojected onto a standard projection with \code{"+proj=longlat +ellps=GRS80 +datum=NAD83 +no_defs"} before being returned.
 #' @return An object of class \code{SpatialPolygonsDataFrame}
-convertLayer <- function(dsn="", layerName="") {
+convertLayer <- function(dsn="", layerName="", encoding=NULL) {
+  
+  # readOGR does not interpret '~' so do that with dirname()
+  dsn <- path.expand(dsn)
   
   # Use package internal data directory
   dataDir <- getSpatialDataDir()
@@ -21,7 +25,7 @@ convertLayer <- function(dsn="", layerName="") {
   setwd(dataDir)
   
   # Load the shapefiles 
-  data_projected <- rgdal::readOGR(dsn=dsn, layer=layerName, stringsAsFactors=FALSE)
+  data_projected <- rgdal::readOGR(dsn=dsn, layer=layerName, stringsAsFactors=FALSE, encoding=encoding)
   
   # Return to user directory
   setwd(oldDir)
